@@ -1,4 +1,5 @@
 from __future__ import annotations
+from functools import partialmethod
 from oslash import Left
 from oslash import Right
 from oslash.either import Either
@@ -86,6 +87,11 @@ class ActionType(type):
         return instance
 
 
+def partialaction(name, parent: ActionType, **kwargs) -> ActionType:
+    partial__init__ = partialmethod(parent.__init__, **kwargs)
+    return type(name, (parent,), {'__init__': partial__init__})
+
+
 class Action(Generic[Name, Outcome], metaclass=ActionType):
 
     _name: Optional[Name] = None
@@ -172,6 +178,9 @@ class Action(Generic[Name, Outcome], metaclass=ActionType):
     class NotComparable(Exception):
         pass
 
+    class Invalid(Exception):
+        pass
+
     class Construct:
         def __init__(self, failure: Exception):
             self.failure = failure
