@@ -1,3 +1,5 @@
+from contextlib import contextmanager
+from io import IOBase as Buffer
 from requests import Response
 from time import sleep
 
@@ -6,6 +8,18 @@ from actionpack.action import Name
 from tests.actionpack import FakeFile
 
 
+@contextmanager
+def uncloseable(buffer: Buffer):
+    """
+    Context manager which turns the fd's close operation to no-op for the duration of the context.
+    """
+    close = buffer.close
+    buffer.close = lambda: None
+    yield buffer
+    buffer.close = close
+    buffer.seek(0)  # fake close
+
+
 class FakeResponse(Response):
     def __init__(self, content: bytes = bytes(), status: int = 200):
         self._content = content
